@@ -33,9 +33,10 @@
 #  define KMM_MYMONEY_DEPRECATED_NO_EXPORT KMM_MYMONEY_NO_EXPORT KMM_MYMONEY_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KMM_MYMONEY_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KMM_MYMONEY_NO_DEPRECATED
+#    define KMM_MYMONEY_NO_DEPRECATED
+#  endif
 #endif
 
-#endif
+#endif /* KMM_MYMONEY_EXPORT_H */
