@@ -33,9 +33,10 @@
 #  define KMM_WIDGETS_DEPRECATED_NO_EXPORT KMM_WIDGETS_NO_EXPORT KMM_WIDGETS_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KMM_WIDGETS_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KMM_WIDGETS_NO_DEPRECATED
+#    define KMM_WIDGETS_NO_DEPRECATED
+#  endif
 #endif
 
-#endif
+#endif /* KMM_WIDGETS_EXPORT_H */
